utils/analyzer_extensions/extensions library

Extensions

AstNodeExt on AstNode
Extension for the AstNode class from the analyzer package. Adds helper methods for working with AST nodes.
BlockFunctionBodyExt on BlockFunctionBody
Extension for the BlockFunctionBody class from the analyzer package. Adds helper methods for working with return statements in block-style function bodies.
ClassNodeExtension on ClassDeclaration
Extension for the ClassDeclaration class from the analyzer package. Adds helper methods for working with class members.
ExpressionFunctionBodyExt on ExpressionFunctionBody
Extension for the ExpressionFunctionBody class from the analyzer package. Adds helper methods for working with expressions in single-expression function bodies.
FunctionBlockBodyExt on FunctionBody
Extension for the FunctionBody class from the analyzer package. Adds helper methods for working with different types of function bodies.
TokenExt on Token
Extension for the Token class from the analyzer package. Adds helper methods for working with tokens.