previousOffset property
int
get
previousOffset
Returns the offset of the previous token relative to the current one.
The offset is calculated as the current offset minus 1.
Return value:
int: The offset of the previous token.
Implementation
int get previousOffset => offset - 1;